summaryrefslogtreecommitdiff
path: root/interface.c
diff options
context:
space:
mode:
authorKlaus Schmidinger <vdr@tvdr.de>2002-06-16 12:57:31 +0200
committerKlaus Schmidinger <vdr@tvdr.de>2002-06-16 12:57:31 +0200
commita4bfddd2f995ad03409de005bc3015437c10aa06 (patch)
treed5959a667bcdb4b7aec55940aaaecfd398de3bb8 /interface.c
parentb005b8fc4a15926ab6f82c7ac19e5b13d811df5f (diff)
downloadvdr-a4bfddd2f995ad03409de005bc3015437c10aa06.tar.gz
vdr-a4bfddd2f995ad03409de005bc3015437c10aa06.tar.bz2
Totally rearranged device/player/recorder structures
Diffstat (limited to 'interface.c')
-rw-r--r--interface.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/interface.c b/interface.c
index 9c2e918d..ed9d0b1e 100644
--- a/interface.c
+++ b/interface.c
@@ -4,7 +4,7 @@
* See the main source file 'vdr.c' for copyright information and
* how to reach the author.
*
- * $Id: interface.c 1.50 2002/05/19 12:02:57 kls Exp $
+ * $Id: interface.c 1.51 2002/06/10 16:30:00 kls Exp $
*/
#include "interface.h"
@@ -484,6 +484,6 @@ void cInterface::DisplayRecording(int Index, bool On)
bool cInterface::Recording(void)
{
- // This is located here because the Interface has to do with the "PrimaryDvbApi" anyway
- return cDvbApi::PrimaryDvbApi->Recording();
+ // This is located here because the Interface has to do with the "PrimaryDevice" anyway
+ return cDevice::PrimaryDevice()->Receiving();
}